<script setup>
import AdminAuthenticatedLayout from '@/Layouts/AdminAuthenticatedLayout.vue';
import InputError from '@/Components/InputError.vue';
import InputLabel from '@/Components/InputLabel.vue';
import PrimaryButton from '@/Components/PrimaryButton.vue';
import TextInput from '@/Components/TextInput.vue';
import MultiSelect from '@/Components/Chosen.vue';
import { ref, onMounted, computed } from 'vue';
import { Head, useForm, usePage } from '@inertiajs/vue3';

const page = usePage();
const product = page.props.product;
const carMakes = computed(() => page.props.carMakes || []);
const carModels = computed(() => page.props.carModels || []);
const carBodyStyles = computed(() => page.props.carBodyStyles || []);

const flashMessage = ref('');
const years = generateYears(1949, new Date().getFullYear()); // Adjust the range as needed

// Transform carMakes data to the format { label: carMake.name, value: carMake.id }
const carMakeOptions = [];
carMakes.value.forEach(item => {
    carMakeOptions.push({
        label: item.name,
        value: item.id
    });
});

// Transform carModels data to the format { label: carModel.name, value: carModel.id }
const carModelOptions = [];
carModels.value.forEach(item => {
    carModelOptions.push({
        label: item.name,
        value: item.id
    });
});

// Transform carBodyStyles data to the format { label: carBodyStyle.name, value: carBodyStyle.id }
const carBodyStyleOptions = [];
carBodyStyles.value.forEach(item => {
    carBodyStyleOptions.push({
        label: item.name,
        value: item.id
    });
});

const form = useForm({
    id: product.id,
    item_number: product.item_number,
    nags_description: product.nags_description,
    item_description: product.item_description,
    data_price: product.data_price,
    price_margin: product.price_margin,
    price: product.price,
    quantity: product.quantity,
    stock: product.stock,
    year: product.year,
    make: product.make,
    model: product.model,
    bodystyle: product.bodystyle,
});

const selectedCarMakes = ref(
  product.make.split(',').map(Number)
);
const selectedCarModels = ref(
  product.model.split(',').map(Number)
);
const selectedCarBodystyles = ref(
  product.bodystyle.split(',').map(Number)
);
const selectedCarYear = ref(
  product.year.split(',').map(Number)
);

// Update the form data with the selected car year
const updateSelectedCarYear = (selected) => {
  selectedCarYear.value = selected;
};

// Update the form data with the selected car makes
const updateSelectedCarMakes = (selected) => {
  selectedCarMakes.value = selected;
};

// Update the form data with the selected car model
const updateSelectedCarModels = (selected) => {
    selectedCarModels.value = selected;
};

// Update the form data with the selected car model
const updateSelectedCarBodystyles = (selected) => {
    selectedCarBodystyles.value = selected;
};

function generateYears(start, end) {
  const years = [];
  for (let year = start; year <= end; year++) {
    years.push(year);
  }
  return years;
}

// console.log(years);
const reversedYears = computed(() => [...years].reverse());
const carYearOptions = [];
reversedYears.value.map(item => {
    const year = item;
    carYearOptions.push({
        label: year.toString().replace(',', ''),
        value: year
    });
});

const productPrice = computed(() => calculatePrice());

const calculatePrice = () => {
    var price = form.price;
    if(form.price_margin) {
        price = parseFloat(form.data_price) + parseFloat(form.data_price * (form.price_margin / 100));
        price = price.toFixed(2);
    }
    return price;
};

const submit = () => {
    const productID = product.id;
    console.log(productID);
    form.year = selectedCarYear.value.join(',');
    form.make = selectedCarMakes.value.join(',');
    form.model = selectedCarModels.value.join(',');
    form.bodystyle = selectedCarBodystyles.value.join(',');
    form.post(route('admin.product.update',{id: productID}), {
        onSuccess: () => {
            flashMessage.value = "Product updated successfully!";
        },
        onError: (error) => {
            console.error(error);
        }
    });
};

onMounted(() => {
    calculatePrice();
});

</script>

<template>

    <Head title="Edit Product" />

    <AdminAuthenticatedLayout>

        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Edit Product <a :href="route('admin.products')"  class="back-btn"> Back to list </a></h2>
        </template>

        <div class="py-12 container">

            <div v-if="flashMessage" class="mx-auto font-bold text-green-600">
                <div class="form-row">
                    <div class="col-12">
                        <h4 class="alert alert-success">{{ flashMessage }}</h4>
                    </div>
                </div>
            </div>

            <div class="content-box sm:rounded-lg">
                <form @submit.prevent="submit">

                    <input type="hidden" id="id" v-model="form.id" />
                    <div class="form-row">

                        <div class="mt-4 col-lg-4 col-md-4 col-sm-6 col-12">
                            <InputLabel for="item_number" value="Item Number" />

                            <TextInput
                                id="item_number"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.item_number"
                                required
                                autofocus
                                autocomplete="item_number"
                            />

                            <InputError class="mt-2" :message="form.errors.item_number" />
                        </div>

                        <div class="mt-4 col-lg-4 col-md-4 col-sm-6 col-12">
                            <InputLabel for="data_price" value="Price" />

                            <TextInput
                                id="data_price"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.data_price"
                                required
                                autofocus
                                autocomplete="data_price"
                            />

                            <InputError class="mt-2" :message="form.errors.data_price" />
                        </div>

                        <div class="mt-4 col-lg-4 col-md-4 col-sm-6 col-12">
                            <InputLabel for="price_percentage" value="Margin Percentage (%)" />

                            <TextInput
                                id="price_margin"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.price_margin"
                                required
                                autofocus
                                autocomplete="price_margin"
                            />

                            <InputError class="mt-2" :message="form.errors.price_margin" />
                        </div>

                        <div class="mt-4 col-lg-4 col-md-4 col-sm-6 col-12">
                            <InputLabel for="price" :value="`${form.price_margin}% of Price`" />

                            <TextInput
                                id="price"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="productPrice"
                                required
                                autofocus
                                autocomplete="price"
                            />

                            <InputError class="mt-2" :message="form.errors.price" />
                        </div>

                        <div class="mt-4 col-lg-4 col-md-4 col-sm-6 col-12">
                            <InputLabel for="quantity" value="Quantity" />

                            <TextInput
                                id="quantity"
                                type="number"
                                class="mt-1 block w-full"
                                v-model="form.quantity"
                                required
                                autofocus
                                autocomplete="quantity"
                            />

                            <InputError class="mt-2" :message="form.errors.quantity" />
                        </div>

                        <div class="mt-4 col-lg-4 col-md-4 col-sm-6 col-12">
                            <InputLabel for="stock" value="Stock" />

                            <select id="stock" class="w-full mt-1 block border-gray-300 rounded-md" v-model="form.stock" required>
                                <option value="">Select</option>
                                <option value="1">In Stock</option>
                                <option value="2">Please Call</option>
                            </select>

                            <InputError class="mt-2" :message="form.errors.stock" />
                        </div>

                        <div class="mt-4 col-12">
                            <InputLabel for="year" value="Year" />
                            <MultiSelect :options="carYearOptions" placeholder="Select Year" :selected="selectedCarYear" @update:selected="updateSelectedCarYear"></MultiSelect>
                            <InputError class="mt-2" :message="form.errors.year" />
                        </div>

                        <div class="mt-4 col-12">
                            <InputLabel for="make" value="Make" />
                            <MultiSelect :options="carMakeOptions" placeholder="Select Make" :selected="selectedCarMakes" @update:selected="updateSelectedCarMakes"></MultiSelect>
                            <InputError class="mt-2" :message="form.errors.make" />
                        </div>

                        <div class="mt-4 col-12">
                            <InputLabel for="model" value="Model" />
                            <MultiSelect :options="carModelOptions" placeholder="Select Model" :selected="selectedCarModels" @update:selected="updateSelectedCarModels"></MultiSelect>
                            <InputError class="mt-2" :message="form.errors.model" />
                        </div>

                        <div class="mt-4 col-12">
                            <InputLabel for="bodystyle" value="Body Style" />
                            <MultiSelect :options="carBodyStyleOptions" placeholder="Select Body Style" :selected="selectedCarBodystyles" @update:selected="updateSelectedCarBodystyles"></MultiSelect>
                            <InputError class="mt-2" :message="form.errors.bodystyle" />
                        </div>

                        <div class="mt-4 col-md-12">
                            <InputLabel for="nags_description" value="Nags Description" />

                            <textarea
                                id="nags_description"
                                v-model="form.nags_description"
                                class="mt-1 block w-full border-gray-300 rounded-md"
                                placeholder="Enter description here..."
                            ></textarea>

                            <InputError class="mt-2" :message="form.errors.nags_description" />
                        </div>

                        <div class="mt-4 col-md-12">
                            <InputLabel for="item_description" value="Description" />

                            <textarea
                                id="item_description"
                                v-model="form.item_description"
                                class="mt-1 block w-full border-gray-300 rounded-md"
                                placeholder="Enter description here..."
                            ></textarea>

                            <InputError class="mt-2" :message="form.errors.item_description" />
                        </div>

                    </div>

                    <div class="flex items-center justify-end my-4 col-md-3 col-12">
                        <PrimaryButton class="btn btn-blue" :class="{ 'opacity-25': form.processing }" :disabled="form.processing">
                            Update Product
                        </PrimaryButton>
                    </div>
                </form>
            </div>
        </div>
    </AdminAuthenticatedLayout>
</template>
